PayFastService class

Service for communicating with PayFast API endpoints.

This service handles token generation and API requests to the PayFast payment gateway. All requests are made to PayFast's token API endpoint: https://ipg1.apps.net.pk/Ecommerce/api/Transaction/GetAccessToken

Constructors

PayFastService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAccessToken({required PayFastConfig config}) Future<String?>
Request an access token from PayFast API.
getToken({required String merchantId, required String securedKey, required String basketId, required String amount}) Future<String?>
Legacy method for backward compatibility